@@ -5,17 +5,17 @@ A lightweight Python SDK for integrating with Go IAM server.
 Provides methods for authentication, user management, and resource creation.
 """
 
+from .models import Resource, User, UserResource, UserRole
 from .service import Service
 from .service_impl import ServiceImpl, new_service
-from .models import User, Resource, UserRole, UserResource
 
 __version__ = "0.0.1"
 __all__ = [
     "Service",
-    "ServiceImpl", 
+    "ServiceImpl",
     "new_service",
     "User",
-    "Resource", 
+    "Resource",
     "UserRole",
-    "UserResource"
+    "UserResource",
 ]
